<TS version="2.1" language="gl_ES">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Fai Click co botón dereito para editar o enderezo ou etiqueta</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Crea un novo enderezo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Novo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">Copia o enderezo seleccionado ao portapapeis do sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Copiar</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">Pechar</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Borra o enderezo seleccionado actualmente da lista</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Introduce un enderezo ou etiqueta para buscar</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Exporta os datos na pestana actual a un ficheiro</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">Exportar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">Borrar</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Selecciona o enderezo ó que enviar moedas</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Selecciona o enderezo do que recibir moedas</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">Selecciona</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">Enderezos de envío</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">Enderezos de recepción</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Estes son os teus enderezos de Bitcoin para enviar pagamentos. Asegurate sempre de comprobar a cantidade e maila dirección antes de enviar moedas.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Estes son os teus enderezos de Bitcoin para recibir pagamentos. Emprega o botón 'Crear novo enderezo para recibir pagamentos' na solapa de recibir para crear novos enderezos.
Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">Copiar Enderezo</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Copia Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">Edita</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Exporta a Lista de Enderezos</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Houbo un erro tentando gardar a lista de enderezos en %1. Por favor proba de novo.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Exportación Fallida</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Enderezo</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Diálogo de Frase Contrasinal</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Introduce a frase contrasinal</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Nova frase contrasinal</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Repite a frase contrasinal</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Mostra frase contrasinal</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Encriptar carteira</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Esta operación necesita da túa frase contrasinal para desbloqueares a carteira.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Desbloquear carteira</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Cambiar frase contrasinal</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Confirmar encriptación da carteira</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Aviso: Si encriptas a túa carteira e perdes a túa frase contrasinal, &lt;b&gt;PERDERÁS TODOS OS TEUS BITCOINS&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">¿Seguro que queres encriptar a túa carteira?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Carteira encriptada</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Introduce unha nova frase contrasinal para a carteira.&lt;br/&gt;Por favor utiliza una frase contrasinal que &lt;b&gt;teña dez ou máis caracteres aleatorios&lt;/b&gt;, ou &lt;b&gt;oito ou máis palabras&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Introduce a frase contrasinal anterior mais a nova frase contrasinal para a carteira.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Recorda que encriptar a tua carteira non protexe completamente que os teus bitcoins poidan ser roubados por malware que afecte ó teu computador.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Carteira para ser encriptada</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">A túa carteira vai a ser encriptada.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">A túa carteira está agora encriptada.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">IMPORTANTE: Calquera copia de respaldo que tiveras feita da túa carteira debería ser sustituída por unha nova copia xerada a partires da túa nova carteira encriptada. Por razóns de seguridade, as copias de respaldo da túa carteira sin encriptar non se poderán usar unha vez que empeces a utilizar a túa nova carteira encriptada.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Error na Encriptación da carteira </translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">A encriptación da carteira fallou debido a un erro interno. A túa carteira no foi encriptada.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">As frases contrasinal introducidas non coinciden.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Desbloqueo de carteira fallido</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">A frase contrasinal introducida para o desencriptamento da carteira é incorrecto.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">A frase contrasinal da carteira mudouse correctamente.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Aviso: ¡A tecla Bloq. Mayús está activada!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP/Máscara de rede</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Vedado ata</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Erro interno</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Cantidade</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;visión xeral</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Mostra una visión xeral da carteira</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Transaccións</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Busca no historial de transaccións</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">S&amp;aír</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Saír da aplicación</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;A cerca de %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Mostra información acerca de %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Mostra información acerca de Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Modifica as opcións de configuración de %1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Crear unha nova carteira</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Minimizar</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Carteira:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Actividade da rede desactivada.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">Proxy &lt;b&gt;activado&lt;/b&gt;: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Envía moedas a un enderezo de Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Respalda a carteira noutro destino</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Cambia a frase contrasinal usada para a encriptación da carteira</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Envía</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Recibir</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Opcións...</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Encripta as claves privadas que pertencen á túa carteira</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Asina mensaxes cos teus enderezos de Bitcoin para probar que che pertencen</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Verifica a mensaxe...</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Verifica mensaxes para asegurar que foron asinados cos enderezos de Bitcoin especificados</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Arquivo</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Opcións</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Axuda</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Barra de ferramentas das pestanas</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Solicita pagamentos (xera un código QR e bitcoin : URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Mostra a lista de enderezos de envío e etiquetas usadas</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Mostra a lista de enderezos de recepción e etiquetas usadas</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Opcións de comando</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 tras</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">O último bloque recibido foi xerado fai %1.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Transaccións despois desta non serán aínda visibles.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Aviso</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Información</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Actualizado</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Xanela de Nodo</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">Abre a consola de depuración e diagnostico do nodo</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Enderezos de envío</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Enderezos de recepción</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">Abre una URI de Bitcoin</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Abrir carteira</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Abrir unha carteira</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Pechar carteira</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Mostra a %1 mensaxe de axuda para obter unha lista cas posibles opcións de línea de comando de Bitcoin </translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">Carteira por defecto</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Non hai carteiras dispoñibles</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Nome da Carteira</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Xanela</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Xanela Principal</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 cliente</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Aviso: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Data: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Cantidade: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Carteira: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Escribe: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Etiqueta: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Enderezo: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Transacción enviada</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Transacción entrante</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation type="unfinished">A xeración de clave HD está &lt;b&gt;activada&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">A xeración de clave HD está &lt;b&gt;desactivada&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Clave privada &lt;b&gt;desactivada&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">A carteira está &lt;b&gt;encrypted&lt;/b&gt; e actualmente &lt;b&gt;desbloqueada&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">A carteira está &lt;b&gt;encriptada&lt;/b&gt; e actualmente &lt;b&gt;bloqueada&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">Mensaxe orixinal:</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">Selección de moeda</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Cantidade:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Cantidade:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">taxa:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation type="unfinished">po:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Despois de taxas:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Cambio:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">(de)seleccionar todo</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Modo en árbore</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Modo en Lista</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Cantidade</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Recibida con etiqueta</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Recibida con enderezo</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Confirmacións</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Confirmada</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Copiar cantidade</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Copiar enderezo</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Copiar cantidade</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Copiar taxa</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Copiar despois de taxa</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Copiar bytes</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation type="unfinished">Copiar po</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Copiar cambio</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(%1 bloqueado)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation type="unfinished">sí</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation type="unfinished">Esta etiqueta tórnase vermella se algún receptor recibe unha cantidade máis pequena que o actual límite de po.</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation type="unfinished">Pode variar +/- %1 satoshi(s) por entrada.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(sin etiqueta)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation type="unfinished">Cambia de %1 a (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(Cambia)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Crea unha Carteira</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation type="unfinished">Creación de carteira fallida</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation type="unfinished">Creación de carteira con aviso</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">Carteira por defecto</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Abrir carteira</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Pechar carteira</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Crea unha Carteira</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Nome da Carteira</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation type="unfinished">Encripta a carteira. A carteira sera encriptada cunha frase contrasinal que tú elixas.</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Encriptar Carteira</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">Opcións avanzadas</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation type="unfinished">Desactiva as claves privadas para esta carteira. Carteiras con claves privadas desactivadas non terán claves privadas e polo tanto non poderan ter unha semente HD ou claves privadas importadas. Esto é ideal para carteiras de solo visualización.</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation type="unfinished">Desactivar Claves Privadas</translation>
    </message>
    <message>
        <source>Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time.</source>
        <translation type="unfinished">Crear unha Carteira en blanco. As carteiras en blanco non teñen inicialmente claves privadas ou scripts. As claves privadas poden ser importadas ou unha semente HD poder ser configurada, máis adiante.</translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation type="unfinished">Crea unha Carteira en Blanco</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">Crea</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Editar Enderezo</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Etiqueta</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation type="unfinished">A etiqueta asociada con esta entrada na lista de enderezos</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation type="unfinished">O enderezo asociado con esta entrada na lista de enderezos. Solo pode ser modificado por enderezos de envío.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Enderezo</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Novo enderezo de envío</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Editar enderezo de recepción</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Editar enderezo de envío</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation type="unfinished">O enderezo introducido "%1" non é un enderezo de Bitcoin válido.</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation type="unfinished">O enderezo "%1" xa existe como un enderezo de recepción ca etiqueta "%2" polo que non pode ser añadido como un enderezo de envío.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation type="unfinished">O enderezo introducido "%1" xa existe na axenda de enderezos ca etiqueta "%2".</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Non se puido desbloquear a carteira.</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Unknown…</source>
        <translation type="unfinished">Descoñecido...</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Xanela</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Continuar</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Save…</source>
        <translation type="unfinished">Gardar...</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">Pechar</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Enderezo</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image…</source>
        <translation type="unfinished">&amp;Gardar Imaxe...</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Xanela de Nodo</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">&amp;Copiar enderezo</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Copiar enderezo</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Non se puido desbloquear a carteira.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Cantidade:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Carteira:</translation>
    </message>
    <message>
        <source>&amp;Save Image…</source>
        <translation type="unfinished">&amp;Gardar Imaxe...</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiqueta</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Cantidade:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Cantidade:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">taxa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Despois de taxas:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Cambio:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation type="unfinished">po:</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Copiar cantidade</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Copiar cantidade</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Copiar taxa</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Copiar despois de taxa</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Copiar bytes</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation type="unfinished">Copiar po</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Copiar cambio</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Cantidade</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiqueta</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Copiar enderezo</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Confirmada</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Enderezo</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Exportación Fallida</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Crear unha nova carteira</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">Carteira por defecto</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">Exportar</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Exporta os datos na pestana actual a un ficheiro</translation>
    </message>
    </context>
</TS>